==> icebear_v1_4_1.tar: install/templates/imagerdb.php <==

<p>Next we need to connect IceBear to RockMaker, by telling IceBear about the RockMaker database and image stores.</p>
<p>We strongly recommend that you create a dedicated SQL Server database user with read-only permissions on the RockImager and RockMaker databases. That database user must be able to connect from the IceBear server, not just from the Formulatrix machines.</p>
<p>Enter the database connection details for your RockMaker installation:</p>

<label>Database host: <input type="text" name="fx_dbhost" value="" /></label>
<label>Database port: <input type="text" name="fx_dbport" value="" /></label>
<label>Database username: <input type="text" name="fx_dbuser" value="" /></label>
<label>Database password: <input type="password" name="fx_dbpass" value="" /></label>
<label>RockMaker database name: <input type="text" name="fx_rmdbname" value="RockMaker" /></label>
<label>RockImager database name: <input type="text" name="fx_ridbname" value="RockImager" /></label>

<p>Once connected to the database, IceBear will find the RockMaker image stores and mount them read-only under /mnt/Formulatrix. You need to provide the network share (Samba) username and password. This is probably something like "formulatrix"/"fmlx_NNN". The network share needs to be visible to the new IceBear server.</p>
<p>Note that only the database credentials are tested at this point. If the image store credentials are incorrect, the stores will not be mounted and you will need to do that manually.</p>
<p>If you have multiple image stores with different usernames and passwords, give one set of credentials here; the other stores will need to be configured manually in /etc/fstab.</p>
<p>Enter the username and password for the network share where the Formulatrix image store is located:</p>
<label>Image store username: <input type="text" name="_isuser" value="" /></label>
<label>Image store password: <input type="password" name="_ispass" value="" /></label>

<p>Set the start date for importing from RockMaker. Images taken on or after this date will be imported into IceBear. If you want everything, choose a date before your imagers were installed.</p>
<label>Import from this date onward (YYYY-MM-DD): <input type="text" name="fx_importfromdate" value="2010-12-31" /></label>

<p>The importer will begin from this date and work forward, once this installation process is complete.</p>

==> icebear_v1_11_0.tar: install/templates/imagerdb.php <==

<p>Next we need to connect IceBear to RockMaker, by telling IceBear about the RockMaker database and image stores.</p>
<p>We strongly recommend that you create a dedicated SQL Server database user with read-only permissions on the RockImager and RockMaker databases. That database user must be able to connect from the IceBear server, not just from the Formulatrix machines.</p>
<p>Enter the database connection details for your RockMaker installation:</p>

<label>Database host: <input type="text" name="fx_dbhost" value="" /></label>
<label>Database port: <input type="text" name="fx_dbport" value="" /></label>
<label>Database username: <input type="text" name="fx_dbuser" value="" /></label>
<label>Database password: <input type="password" name="fx_dbpass" value="" /></label>
<label>RockMaker database name: <input type="text" name="fx_rmdbname" value="RockMaker" /></label>
<label>RockImager database name: <input type="text" name="fx_ridbname" value="RockImager" /></label>

<p>Once connected to the database, IceBear will find the RockMaker image stores and mount them read-only under /mnt/Formulatrix. You need to provide the network share (Samba) username and password. This is probably something like "formulatrix"/"fmlx_NNN". The network share needs to be visible to the new IceBear server.</p>
<p>Note that only the database credentials are tested at this point. If the image store credentials are incorrect, the stores will not be mounted, and you will need to do that manually.</p>
<p>If you have multiple image stores with different usernames and passwords, give one set of credentials here; the other stores will need to be configured manually in /etc/fstab.</p>
<p>Enter the username and password for the network share where the Formulatrix image store is located:</p>
<label>Image store username: <input type="text" name="_isuser" value="" /></label>
<label>Image store password: <input type="password" name="_ispass" value="" /></label>

<p>Set the start date for importing from RockMaker. Images taken on or after this date will be imported into IceBear. If you want everything, choose a date before your imagers were installed.</p>
<label>Import from this date onward (YYYY-MM-DD): <input type="text" name="fx_importfromdate" value="2010-12-31" /></label>

<p>The importer will begin from this date and work forward, once this installation process is complete.</p>
